@@ -6,7 +6,7 @@
 #' @param data the data set that contains the variables. 
 #' Must contain columns named: time, censor_time,rx, arm.
 #' Optionally a column named: treat_modifier
-#' @param formula a forumula object of covariates to adjust for: \code{~strata(A)+B*C}
+#' @param formula a formula object of covariates to adjust for: \code{~strata(A)+B*C}
 #' @param target the value to subtract off from the z-statistic 
 #' @param test the survival regression function to calculate the z-statistic: survdiff, coxph, survreg
 #' @param ... arguments to supply to the test function.
@@ -25,7 +25,7 @@ est_eqn <- function(psi, data, formula, target = 0, test = "survdiff",
   }
   
   Sstar <- untreated(psi, data[, "time"], data[, "status"], data[,"(censor_time)"],
-                     data[,"rx"], data[, "arm"],  autoswitch)
+                     data[,".rx"], data[, ".arm"],  autoswitch)
   data <- cbind(Sstar, data)
   # build a formula object,
   fit_formula <- update(formula, Sstar ~ .)
@@ -35,7 +35,7 @@ est_eqn <- function(psi, data, formula, target = 0, test = "survdiff",
   fit <- do.call(functionName, list(fit_formula, data, ...))
   # a 'cheat' to enable this to plugged into uniroot as a function that
   # returns a number AND store the fit object.
-  .value <- extract_z(fit, arm = "arm") - target
+  .value <- extract_z(fit, arm = ".arm") - target
   attr(.value, "fit") <- fit
   .value
 }
\ No newline at end of file
