@@ -6,16 +6,17 @@
 #'
 #'@return a list of variables referred to in a formula or call object
 #'@param x an R object
+#'@param ... extendible arguments to the S3 method
 #'@return a character vector
 #'@importFrom survival Surv
 #'@keywords internal
 
-terms.inner <- function (x) 
+terms.inner <- function (x,...) 
 {
   #if (class(x) == "formula") 
   #  c(terms.inner(x[[2]]), terms.inner(x[[3]]))
   #else 
-  if (class(x) == "call" && (x[[1]] != as.name("$") && 
+  if (inherits(x,"call") && (x[[1]] != as.name("$") && 
                                   x[[1]] != as.name("["))) {
     if (x[[1]] == "+" || x[[1]] == "*" || x[[1]] == "-") {
       c(terms.inner(x[[2]]), terms.inner(x[[3]]))
